@@ -2,7 +2,8 @@ def encode_node(name, content):
     if isinstance(content, dict):
         return b"/" + name + b"/\n" + encode_nodes(content) + b"\\\n"
     t, content = {"-": b":", "x": b"!", "l": b"@"}[content[0]], content[1]
-    return t + name + b"/\n" + content.replace(b" ~ ~", b"\ ~ ~") + b"~ ~ ~\n"
+    content = content.replace(b" ~ ~\n", b"\ ~ ~\n") + b"~ ~ ~\n"
+    return t + name + b"/\n" + content
 
 
 def encode_nodes(nodes):
